<?php

namespace ShineSoftware\Constriv\Block\Moto;

use Magento\Framework\View\Element\Template\Context;
use Magento\Payment\Block\Form\Cc;
use Magento\Payment\Model\Config;
use Magento\Store\Model\ScopeInterface;
use ShineSoftware\Constriv\Model\Config as ModelConfig;
use ShineSoftware\Constriv\Model\Source\Gateway;

class Form extends Cc {

    /**
     * @var ModelConfig
     */
    protected $_modelConfig;

    public function __construct(Context $context, Config $paymentConfig, ModelConfig $modelConfig, array $data = []) {
        $this->_modelConfig = $modelConfig;

        parent::__construct($context, $paymentConfig, $data);
    }

    protected function _construct() {
        parent::_construct();
        $this->setTemplate('ShineSoftware_Constriv::constriv/moto/form.phtml');
    }

    protected function _getConfig() {
        return $this->_modelConfig;
    }

    public function getCcMonths() {
        $months = $this->getData('cc_months');
        if (is_null($months)) {
            $months[0] = __('Month');
            $months = array_merge($months, $this->_getConfig()->getMonths());
            $this->setData('cc_months', $months);
        }
        return $months;
    }

    public function getCcYears() {
        $years = $this->getData('cc_years');
        if (is_null($years)) {
            $years = $this->_getConfig()->getYears();
            $years = [0 => __('Year')] + $years;
            $this->setData('cc_years', $years);
        }
        return $years;
    }

    public function getCcAvailableTypes() {
        $types = Gateway::getCollection();
        if ($method = $this->getMethod()) {
            $availableTypes = $this->_scopeConfig->getValue('payment/constriv_moto_required_settings/cctypes', ScopeInterface::SCOPE_STORE);
            if ($availableTypes) {
                $availableTypes = explode(',', $availableTypes);
                foreach ($types as $code => $name) {
                    if (!in_array($code, $availableTypes)) {
                        unset($types[$code]);
                    }
                }
            }
        }
        return $types;
    }

}

;
